@@ -44,6 +44,8 @@
 #include "gnome-i18nP.h"
 
 #include <libgnome/libgnome.h>
+#include <bonobo/bonobo-ui-main.h>
+#include <gconf/gconf-client.h>
 
 #include "gnome-client.h"
 #include "gnome-gconf-ui.h"
@@ -56,33 +58,66 @@
 
 #include <gtk/gtkversion.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkaccelmap.h>
+
+/* for sound events */
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkcheckmenuitem.h>
+#include <gtk/gtkmessagedialog.h>
 
 /*****************************************************************************
  * libgnomeui
  *****************************************************************************/
 
-static void libgnomeui_arg_callback(poptContext con,
-                                    enum poptCallbackReason reason,
-                                    const struct poptOption * opt,
-                                    const char * arg, void * data);
-static void libgnomeui_init_pass(const GnomeModuleInfo *mod_info);
-static void libgnomeui_class_init(GnomeProgramClass *klass, const GnomeModuleInfo *mod_info);
-static void libgnomeui_instance_init(GnomeProgram *program, GnomeModuleInfo *mod_info);
-static void libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
-static void libgnomeui_post_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
-static void libgnomeui_rc_parse (gchar *command);
-static void libgnomeui_segv_setup(gboolean post_arg_parse);
+static void libgnomeui_arg_callback 	(poptContext con,
+					 enum poptCallbackReason reason,
+					 const struct poptOption * opt,
+					 const char * arg,
+					 void * data);
+static void libgnomeui_init_pass	(const GnomeModuleInfo *mod_info);
+static void libgnomeui_class_init	(GnomeProgramClass *klass,
+					 const GnomeModuleInfo *mod_info);
+static void libgnomeui_instance_init	(GnomeProgram *program,
+					 GnomeModuleInfo *mod_info);
+static void libgnomeui_pre_args_parse	(GnomeProgram *app,
+					 GnomeModuleInfo *mod_info);
+static void libgnomeui_post_args_parse	(GnomeProgram *app,
+					 GnomeModuleInfo *mod_info);
+static void libgnomeui_rc_parse		(GnomeProgram *program,
+					 const gchar *command);
+static void libgnomeui_segv_setup	(GnomeProgram *program,
+					 gboolean post_arg_parse);
+
+/* Prototype for a private gnome_stock function */
+void _gnome_stock_icons_init (void);
+
+#ifdef HAVE_ESD
+
+/* Whether to make noises when the user clicks a button, etc.  We cache it
+ * in a boolean rather than querying GConf every time.
+ */
+static gboolean use_event_sounds;
+
+/* GConf client for monitoring the event sounds option */
+static GConfClient *gconf_client = NULL;
+
+#endif /* HAVE_ESD */
+
 
 enum { ARG_DISABLE_CRASH_DIALOG=1, ARG_DISPLAY };
 
 static struct poptOption libgnomeui_options[] = {
-        {NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE, 0, NULL, NULL},
+        {NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
 	{NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE|POPT_CBFLAG_POST,
 	 &libgnomeui_arg_callback, 0, NULL, NULL},
-	{"disable-crash-dialog", '\0', POPT_ARG_NONE, NULL, ARG_DISABLE_CRASH_DIALOG},
+	{"disable-crash-dialog", '\0', POPT_ARG_NONE, NULL, ARG_DISABLE_CRASH_DIALOG,
+        N_("Disable Crash Dialog"), NULL},
         {"display", '\0', POPT_ARG_STRING|POPT_ARGFLAG_DOC_HIDDEN, NULL, ARG_DISPLAY,
          N_("X display to use"), N_("DISPLAY")},
-	{NULL, '\0', 0, NULL, 0}
+	{NULL, '\0', 0, NULL, 0, NULL, NULL}
 };
 
 const GnomeModuleInfo *
@@ -100,23 +135,19 @@ libgnomeui_module_info_get (void)
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[6];
 
-		req[0].required_version = "1.3.7";
-		req[0].module_info = gnome_gtk_module_info_get ();
+		bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
 
-		req[1].required_version = "1.102.0";
-		req[1].module_info = LIBGNOME_MODULE;
+		req[0].required_version = "1.101.2";
+		req[0].module_info = LIBBONOBOUI_MODULE;
 
-		req[2].required_version = "1.101.2";
-		req[2].module_info = GNOME_BONOBO_MODULE;
+		req[1].required_version = VERSION;
+		req[1].module_info = gnome_client_module_info_get ();
 
-		req[3].required_version = "1.1.1";
-		req[3].module_info = gnome_gconf_ui_module_info_get ();
+		req[2].required_version = "1.1.1";
+		req[2].module_info = gnome_gconf_ui_module_info_get ();
 
-		req[4].required_version = VERSION;
-		req[4].module_info = gnome_client_module_info_get ();
-
-		req[5].required_version = NULL;
-		req[5].module_info = NULL;
+		req[3].required_version = NULL;
+		req[3].module_info = NULL;
 
 		module_info.requirements = req;
 	}
@@ -247,8 +278,6 @@ libgnomeui_instance_init (GnomeProgram *program, GnomeModuleInfo *mod_info)
 static void
 libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 {
-        gboolean ctype_set;
-        char *ctype, *old_ctype = NULL;
         gboolean do_crash_dialog = TRUE;
         const char *envar;
 
@@ -261,48 +290,273 @@ libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 			      NULL);
 
         if(do_crash_dialog)
-                libgnomeui_segv_setup(FALSE);
+                libgnomeui_segv_setup (app, FALSE);
+}
 
-        /* Begin hack to propogate an en_US locale into Gtk+ if LC_CTYPE=C, so that non-ASCII
-           characters will display for as many people as possible. Related to bug #1979 */
-        ctype = setlocale (LC_CTYPE, NULL);
+#ifdef HAVE_ESD
+static gboolean
+relay_gnome_signal (GSignalInvocationHint *hint,
+              	     guint n_param_values,
+                    const GValue *param_values,
+                    gchar *signame)
+{
+        char *pieces[3] = {"gnome-2", NULL, NULL};
+        static GQuark disable_sound_quark = 0;
+        GObject *object = g_value_get_object (&param_values[0]);
 
-        if (strcmp (ctype, "C") == 0) {
-                old_ctype = g_strdup (g_getenv ("LC_CTYPE"));
-                gnome_setenv ("LC_CTYPE", "en_US", TRUE);
-                ctype_set = TRUE;
-        } else {
-                ctype_set = FALSE;
+        if (!use_event_sounds)
+                return TRUE;
+
+        if (!disable_sound_quark)
+                disable_sound_quark = g_quark_from_static_string ("gnome_disable_sound_events");
+
+        if (g_object_get_qdata (object, disable_sound_quark))
+                return TRUE;
+
+        if (GTK_IS_WIDGET (object)) {
+
+                if (!GTK_WIDGET_DRAWABLE (object))
+                        return TRUE;
+
+                if (GTK_IS_MESSAGE_DIALOG (object)) {
+                        GtkMessageType message_type;
+                        g_object_get (object, "message_type", &message_type, NULL);
+                        switch (message_type)
+                        {
+                                case GTK_MESSAGE_INFO:
+                                        pieces[1] = "info";
+                                        break;
+
+                                case GTK_MESSAGE_QUESTION:
+                                        pieces[1] = "question";
+                                        break;
+
+                                case GTK_MESSAGE_WARNING:
+                                        pieces[1] = "warning";
+                                        break;
+
+                                case GTK_MESSAGE_ERROR:
+                                        pieces[1] = "error";
+                                        break;
+
+                                default:
+                                        pieces[1] = NULL;
+                        }
+                }
+        }
+
+        if (gnome_sound_connection_get () < 0)
+                return TRUE;
+
+        gnome_triggers_vdo ("", NULL, (const char **) pieces);
+
+        return TRUE;
+}
+
+static void
+initialize_gnome_signal_relay (void)
+{
+        static gboolean initialized = FALSE;
+        int signum;
+
+        if (initialized)
+                return;
+
+        initialized = TRUE;
+
+        signum = g_signal_lookup ("show", GTK_TYPE_MESSAGE_DIALOG);
+        g_signal_add_emission_hook (signum, 0,
+                                    (GSignalEmissionHook) relay_gnome_signal,
+                                    NULL, NULL);
+
+}
+
+static gboolean
+relay_gtk_signal(GSignalInvocationHint *hint,
+		 guint n_param_values,
+		 const GValue *param_values,
+		 gchar *signame)
+{
+  char *pieces[3] = {"gtk-events-2", NULL, NULL};
+  static GQuark disable_sound_quark = 0;
+  GObject *object = g_value_get_object (&param_values[0]);
+
+  pieces[1] = signame;
+
+  if (!use_event_sounds)
+    return TRUE;
+
+  if(!disable_sound_quark)
+    disable_sound_quark = g_quark_from_static_string("gnome_disable_sound_events");
+
+  if(g_object_get_qdata (object, disable_sound_quark))
+    return TRUE;
+
+  if(GTK_IS_WIDGET(object)) {
+    if(!GTK_WIDGET_DRAWABLE(object))
+      return TRUE;
+
+    if(GTK_IS_MENU_ITEM(object) && GTK_MENU_ITEM(object)->submenu)
+      return TRUE;
+  }
+
+  if (gnome_sound_connection_get() < 0)
+    return TRUE;
+
+  gnome_triggers_vdo("", NULL, (const char **)pieces);
+
+  return TRUE;
+}
+
+static void
+initialize_gtk_signal_relay (void)
+{
+	gpointer iter_signames;
+	char *signame;
+	char *ctmp, *ctmp2;
+        static gboolean initialized = FALSE;
+
+        if (initialized)
+                return;
+
+        initialized = TRUE;
+	
+	ctmp = gnome_config_file ("/sound/events/gtk-events-2.soundlist");
+	ctmp2 = g_strconcat ("=", ctmp, "=", NULL);
+	g_free (ctmp);
+	iter_signames = gnome_config_init_iterator_sections (ctmp2);
+	gnome_config_push_prefix (ctmp2);
+	g_free (ctmp2);
+	
+	while ((iter_signames = gnome_config_iterator_next (iter_signames,
+							    &signame, NULL))) {
+		int signums [5];
+		int nsigs, i;
+		gboolean used_signame;
+
+		/*
+		 * XXX this is an incredible hack based on a compile-time
+		 * knowledge of what gtk widgets do what, rather than
+		 * anything based on the info available at runtime.
+		 */
+		if (!strcmp (signame, "activate")) {
+			g_type_class_unref (g_type_class_ref (gtk_menu_item_get_type ()));
+			signums [0] = g_signal_lookup (signame, gtk_menu_item_get_type ());
+			
+			g_type_class_unref (g_type_class_ref (gtk_entry_get_type ()));
+			signums [1] = g_signal_lookup (signame, gtk_entry_get_type ());
+			nsigs = 2;
+		} else if (!strcmp(signame, "toggled")) {
+			g_type_class_unref (g_type_class_ref (gtk_toggle_button_get_type ()));
+			signums [0] = g_signal_lookup (signame,
+							 gtk_toggle_button_get_type ());
+			
+			g_type_class_unref (g_type_class_ref (gtk_check_menu_item_get_type ()));
+			signums [1] = g_signal_lookup (signame,
+							 gtk_check_menu_item_get_type ());
+			nsigs = 2;
+		} else if (!strcmp (signame, "clicked")) {
+			g_type_class_unref (g_type_class_ref (gtk_button_get_type ()));
+			signums [0] = g_signal_lookup (signame, gtk_button_get_type ());
+			nsigs = 1;
+		} else {
+			g_type_class_unref (g_type_class_ref (gtk_widget_get_type ()));
+			signums [0] = g_signal_lookup (signame, gtk_widget_get_type ());
+			nsigs = 1;
+		}
+
+		used_signame = FALSE;
+		for (i = 0; i < nsigs; i++) {
+			if (signums [i] > 0) {
+				g_signal_add_emission_hook (
+                                        signums [i], 0,
+                                        (GSignalEmissionHook) relay_gtk_signal,
+                                        signame, NULL);
+                                used_signame = TRUE;
+                        }
+                }
+
+                if (!used_signame)
+                        g_free (signame);
+	}
+	gnome_config_pop_prefix ();
+}
+
+/* Callback used when the GConf event_sounds key's value changes */
+static void
+event_sounds_changed_cb (GConfClient* client, guint cnxn_id, GConfEntry *entry, gpointer data)
+{
+        gboolean new_use_event_sounds;
+
+        new_use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
+                                gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
+
+        if (new_use_event_sounds && !use_event_sounds) {
+                initialize_gtk_signal_relay ();
+                initialize_gnome_signal_relay ();
 	}
 
-        gtk_set_locale ();
+        use_event_sounds = new_use_event_sounds;
+}
+#endif
 
-        if (ctype_set) {
-                if (old_ctype) {
-			gnome_setenv ("LC_CTYPE", old_ctype, TRUE);
-                        g_free (old_ctype);
-                } else {
-			gnome_unsetenv ("LC_CTYPE");
-		}
-        }
-        /* End hack */
+static void
+setup_event_listener (void)
+{
+#ifdef HAVE_ESD
+        gconf_client = gconf_client_get_default ();
+        if (!gconf_client)
+                return;
+
+        gconf_client_add_dir (gconf_client, "/desktop/gnome/sound",
+                              GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+
+        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/event_sounds",
+                                 event_sounds_changed_cb,
+                                 NULL, NULL, NULL);
+        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/enable_esd",
+                                 event_sounds_changed_cb,
+                                 NULL, NULL, NULL);
+	
+        use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
+                            gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
+
+        if (use_event_sounds) {
+                initialize_gtk_signal_relay ();
+                initialize_gnome_signal_relay ();
+	 }
+#endif
 }
 
 static void
 libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 {
-        GnomeProgramPrivate_libgnomeui *priv = g_new0(GnomeProgramPrivate_libgnomeui, 1);
+        GnomeProgramPrivate_libgnomeui *priv;
+        gchar *filename;
 
         gnome_type_init();
-        /* #warning FIXME: here... gtk_rc ... */
-        libgnomeui_rc_parse(program_invocation_name);
+        libgnomeui_rc_parse (program, g_get_prgname ());
 
-        libgnomeui_segv_setup(TRUE);
+        libgnomeui_segv_setup (program, TRUE);
 
         priv = g_object_get_qdata(G_OBJECT(program), quark_gnome_program_private_libgnomeui);
         priv->constructed = TRUE;
 
-        init_gnome_stock_icons ();
+        /* load the accelerators */
+        filename = g_build_filename (gnome_user_accels_dir_get (),
+                                     gnome_program_get_app_id (program),
+                                     NULL);
+        gtk_accel_map_load (filename);
+        g_free (filename);
+
+	bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
+#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+
+        _gnome_stock_icons_init ();
+
+        setup_event_listener ();
 }
 
 static void
@@ -311,7 +565,8 @@ libgnomeui_arg_callback(poptContext con,
                         const struct poptOption * opt,
                         const char * arg, void * data)
 {
-        GnomeProgram *program = gnome_program_get ();
+        GnomeProgram *program = g_dataset_get_data (con, "GnomeProgram");
+	g_assert (program != NULL);
 
         switch(reason) {
         case POPT_CALLBACK_REASON_OPTION:
@@ -345,14 +600,14 @@ libgnomeui_arg_callback(poptContext con,
  * It provides good consistancy (you always know the rc file will be
  * the same name as the executable), and it's easy for the programmer.
  * 
- * If you don't like it.. give me a good reason.  Symlin
+ * If you don't like it.. give me a good reason.
  */
 static void
-libgnomeui_rc_parse (gchar *command)
+libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
 {
 	gint i;
 	gint buf_len;
-	gchar *buf = NULL;
+	const gchar *buf = NULL;
 	gchar *file;
 	gchar *apprc;
 	
@@ -374,9 +629,9 @@ libgnomeui_rc_parse (gchar *command)
 	/* <gnomedatadir>/gtkrc */
         file = gnome_program_locate_file (gnome_program_get (),
                                           GNOME_FILE_DOMAIN_DATADIR,
-                                          "gtkrc", TRUE, NULL);
+                                          "gtkrc-2.0", TRUE, NULL);
   	if (file) {
-  		gtk_rc_add_default_file (file); 
+  		gtk_rc_parse (file); 
 		g_free (file);
 	}
 
@@ -385,21 +640,21 @@ libgnomeui_rc_parse (gchar *command)
                                           GNOME_FILE_DOMAIN_DATADIR,
                                           apprc, TRUE, NULL);
 	if (file) {
-                gtk_rc_add_default_file (file);
+                gtk_rc_parse (file);
                 g_free (file);
         }
 	
 	/* ~/.gnome/gtkrc */
-	file = gnome_util_home_file("gtkrc");
+	file = gnome_util_home_file("gtkrc-2.0");
 	if (file) {
-		gtk_rc_add_default_file (file);
+		gtk_rc_parse (file);
 		g_free (file);
 	}
 	
 	/* ~/.gnome/<progname> */
 	file = gnome_util_home_file(apprc);
 	if (file) {
-		gtk_rc_add_default_file (file);
+		gtk_rc_parse (file);
 		g_free (file);
 	}
 }
@@ -408,7 +663,7 @@ libgnomeui_rc_parse (gchar *command)
 static void libgnomeui_segv_handle(int signum);
 
 static void
-libgnomeui_segv_setup(gboolean post_arg_parse)
+libgnomeui_segv_setup (GnomeProgram *program, gboolean post_arg_parse)
 {
         static struct sigaction *setptr;
         struct sigaction sa;
@@ -416,30 +671,33 @@ libgnomeui_segv_setup(gboolean post_arg_parse)
         GValue value = { 0, };
 
         g_value_init (&value, G_TYPE_BOOLEAN);
-        g_object_get_property (G_OBJECT (gnome_program_get()),
+        g_object_get_property (G_OBJECT (program),
                                LIBGNOMEUI_PARAM_CRASH_DIALOG, &value);
         do_crash_dialog = g_value_get_boolean (&value);
         g_value_unset (&value);
 
-        memset(&sa, 0, sizeof(sa));
-
-        setptr = &sa;
         if(do_crash_dialog) {
+                memset(&sa, 0, sizeof(sa));
+                setptr = &sa;
+
                 sa.sa_handler = (gpointer)libgnomeui_segv_handle;
-        } else {
-                sa.sa_handler = SIG_DFL;
+
+                sigaction(SIGSEGV, setptr, NULL);
+                sigaction(SIGABRT, setptr, NULL);
+                sigaction(SIGTRAP, setptr, NULL);
+                sigaction(SIGFPE, setptr, NULL);
+                sigaction(SIGBUS, setptr, NULL);
         }
 
-        sigaction(SIGSEGV, setptr, NULL);
-        sigaction(SIGFPE, setptr, NULL);
-        sigaction(SIGBUS, setptr, NULL);
 }
 
 static void libgnomeui_segv_handle(int signum)
 {
 	static int in_segv = 0;
+        struct sigaction sa;
 	pid_t pid;
 	
+	sa.sa_handler = NULL;
 	in_segv++;
 
         if (in_segv > 2) {
@@ -465,8 +723,12 @@ static void libgnomeui_segv_handle(int signum)
 				   "Cannot display crash dialog\n"));
 
                 /* Don't use app attributes here - a lot of things are probably hosed */
-		if (g_getenv ("GNOME_DUMP_CORE"))
+		if (g_getenv ("GNOME_DUMP_CORE")) {
+                        /* Reset SIGABRT so we don't get called again. */
+                        sa.sa_handler = SIG_DFL;
+                        sigaction (SIGABRT, &sa, NULL);
 	                abort ();
+                }
 
 		_exit(1);
 	} else if (pid > 0) {
@@ -479,8 +741,12 @@ static void libgnomeui_segv_handle(int signum)
 		eret = waitpid(pid, &estatus, 0);
 
                 /* Don't use app attributes here - a lot of things are probably hosed */
-		if(g_getenv("GNOME_DUMP_CORE"))
+		if(g_getenv("GNOME_DUMP_CORE")) {
+                        /* Reset SIGABRT so we don't get called again. */
+                        sa.sa_handler = SIG_DFL;
+                        sigaction (SIGABRT, &sa, NULL);
 	                abort ();
+                }
 
 		_exit(1);
 	} else /* pid == 0 */ {
@@ -492,12 +758,12 @@ static void libgnomeui_segv_handle(int signum)
                 program = gnome_program_get();
 
 		/* Child process */
-		execl (GNOMEUIBINDIR "/gnome_segv2", GNOMEUIBINDIR "/gnome_segv",
-		       gnome_program_get_app_id (program), buf,
+		execl (GNOMEUISERVERDIR "/gnome_segv2", GNOMEUISERVERDIR "/gnome_segv",
+		       g_get_prgname (), buf,
 		       gnome_program_get_app_version (program), NULL);
 
                 execlp ("gnome_segv2", "gnome_segv2",
-			gnome_program_get_app_id (program), buf,
+			g_get_prgname (), buf,
 			gnome_program_get_app_version (program), NULL);
 
                 _exit(99);
@@ -521,13 +787,15 @@ static void libgnomeui_segv_handle(int signum)
  *
  * Initializes the application.  This sets up all of the GNOME
  * internals and prepares them (imlib, gdk, session-management, triggers,
- * sound, user preferences)
+ * sound, user preferences).
  *
  * Unlike #gnome_init, with #gnome_init_with_popt_table you can provide
  * a table of popt options (popt is the command line argument parsing
  * library).
  *
- * Deprecated, use #gnome_program_init with the LIBGNOMEUI_MODULE
+ * Deprecated, use #gnome_program_init with the LIBGNOMEUI_MODULE.
+ *
+ * Returns: 0 (always)
  */
 int
 gnome_init_with_popt_table (const char *app_id,
@@ -537,18 +805,19 @@ gnome_init_with_popt_table (const char *app_id,
 			    int flags,
 			    poptContext *return_ctx)
 {
-        gnome_program_init (app_id, app_version,
-			    LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_POPT_TABLE, options,
-			    GNOME_PARAM_POPT_FLAGS, flags,
-			    NULL);
+	GnomeProgram *program;
+        program = gnome_program_init (app_id, app_version,
+				      LIBGNOMEUI_MODULE,
+				      argc, argv,
+				      GNOME_PARAM_POPT_TABLE, options,
+				      GNOME_PARAM_POPT_FLAGS, flags,
+				      NULL);
 
         if(return_ctx) {
                 GValue value = { 0, };
 
                 g_value_init (&value, G_TYPE_POINTER);
-                g_object_get_property (G_OBJECT (gnome_program_get()),
+                g_object_get_property (G_OBJECT (program),
                                        GNOME_PARAM_POPT_CONTEXT, &value);
                 *return_ctx = g_value_peek_pointer (&value);
                 g_value_unset (&value);
@@ -557,190 +826,8 @@ gnome_init_with_popt_table (const char *app_id,
         return 0;
 }
 
-/**
- * gnome_init:
- * @app_id: Application id.
- * @app_version: Application version.
- * @argc: argument count (for example argc as received by main)
- * @argv: argument vector (for example argv as received by main)
- *
- * Initializes the application.  This sets up all of the GNOME
- * internals and prepares them (imlib, gdk, session-management, triggers,
- * sound, user preferences)
- * Deprecated, use #gnome_program_init with the LIBGNOMEUI_MODULE
- */
-/* This is a macro */
-
-
-/*
- * GTK init stuff
- */
-
-typedef struct {
-	GPtrArray *gtk_args;
-} gnome_gtk_init_info;
-
-static void add_gtk_arg_callback (poptContext con,
-				  enum poptCallbackReason reason,
-				  const struct poptOption * opt,
-				  const char * arg, void * data);
-
-static struct poptOption gtk_options [] = {
-	{ NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE,
-	  &add_gtk_arg_callback, 0, NULL, NULL },
-
-	{ NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE, 0, NULL, NULL },
-
-	{ "gdk-debug", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Gdk debugging flags to set"), N_("FLAGS")},
-
-	{ "gdk-no-debug", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Gdk debugging flags to unset"), N_("FLAGS")},
-
-	{ "display", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("X display to use"), N_("DISPLAY")},
-
-	{ "sync", '\0', POPT_ARG_NONE, NULL, 0,
-	  N_("Make X calls synchronous"), NULL},
-
-	{ "no-xshm", '\0', POPT_ARG_NONE, NULL, 0,
-	  N_("Don't use X shared memory extension"), NULL},
-
-	{ "name", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Program name as used by the window manager"), N_("NAME")},
-
-	{ "class", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Program class as used by the window manager"), N_("CLASS")},
-
-	{ "gxid_host", '\0', POPT_ARG_STRING, NULL, 0,
-	  NULL, N_("HOST")},
-
-	{ "gxid_port", '\0', POPT_ARG_STRING, NULL, 0,
-	  NULL, N_("PORT")},
-
-	{ "xim-preedit", '\0', POPT_ARG_STRING, NULL, 0,
-	  NULL, N_("STYLE")},
-
-	{ "xim-status", '\0', POPT_ARG_STRING, NULL, 0,
-	  NULL, N_("STYLE")},
-
-	{ "gtk-debug", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Gtk+ debugging flags to set"), N_("FLAGS")},
-
-	{ "gtk-no-debug", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Gtk+ debugging flags to unset"), N_("FLAGS")},
-
-	{ "g-fatal-warnings", '\0', POPT_ARG_NONE, NULL, 0,
-	  N_("Make all warnings fatal"), NULL},
-
-	{ "gtk-module", '\0', POPT_ARG_STRING, NULL, 0,
-	  N_("Load an additional Gtk module"), N_("MODULE")},
-
-	{ NULL, '\0', 0, NULL, 0}
-};
-
-
-static void
-gtk_pre_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
-{
-	struct poptOption *options, *ptr;
-	gnome_gtk_init_info *init_info = g_new0 (gnome_gtk_init_info, 1);
-	guint count = 1;
-
-	for (ptr = gtk_options;
-	     (ptr->argInfo != POPT_ARG_NONE) || (ptr->descrip != NULL);
-	     ptr++)
-		count++;
-
-	options = g_memdup (gtk_options, sizeof (struct poptOption) * count);
-	options->descrip = (const char *) init_info;
-
-	init_info->gtk_args = g_ptr_array_new ();
-
-	mod_info->options = options;
-}
-
-static void
-gtk_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
-{
-	gnome_gtk_init_info *init_info;
-	int final_argc;
-	char **final_argv;
-
-	init_info = (gnome_gtk_init_info *) mod_info->options [0].descrip;
-
-	g_ptr_array_add (init_info->gtk_args, NULL);
-
-	final_argc = init_info->gtk_args->len - 1;
-	final_argv = g_memdup (init_info->gtk_args->pdata,
-			       sizeof (char *) * init_info->gtk_args->len);
-
-	gtk_init (&final_argc, &final_argv);
-
-	gdk_rgb_init();
-
-	g_free (mod_info->options);
-	mod_info->options = NULL;
-
-	g_ptr_array_free (init_info->gtk_args, TRUE);
-	g_free (init_info);
-}
-
-
-
-static void
-add_gtk_arg_callback (poptContext con, enum poptCallbackReason reason,
-		      const struct poptOption * opt,
-		      const char * arg, void * data)
-{
-	gnome_gtk_init_info *init_info = data;
-	char *newstr;
-
-	switch (reason) {
-	case POPT_CALLBACK_REASON_PRE:
-		/* Note that the value of argv[0] passed to main() may be
-		 * different from the value that this passes to gtk
-		 */
-		g_ptr_array_add (init_info->gtk_args,
-				 (char *) g_strdup (poptGetInvocationName (con)));
-		break;
-		
-	case POPT_CALLBACK_REASON_OPTION:
-		switch (opt->argInfo) {
-		case POPT_ARG_STRING:
-		case POPT_ARG_INT:
-		case POPT_ARG_LONG:
-			newstr = g_strconcat ("--", opt->longName, "=", arg, NULL);
-			break;
-		default:
-			newstr = g_strconcat ("--", opt->longName, NULL);
-			break;
-		}
-
-		g_ptr_array_add (init_info->gtk_args, newstr);
-		/* XXX gnome-client tie-in */
-		break;
-	default:
-		break;
-	}
-}
-
 const GnomeModuleInfo *
 gnome_gtk_module_info_get (void)
 {
-	static GnomeModuleInfo module_info = {
-		"gtk", NULL, N_("GTK+"),
-		NULL, NULL,
-		gtk_pre_args_parse, gtk_post_args_parse, gtk_options,
-		NULL,
-		NULL, NULL, NULL
-	};
-	if (module_info.version == NULL) {
-		module_info.version = g_strdup_printf ("%d.%d.%d",
-						       GTK_MAJOR_VERSION,
-						       GTK_MINOR_VERSION,
-						       GTK_MICRO_VERSION);
-	}
-
-	return &module_info;
+        return bonobo_ui_gtk_module_info_get ();
 }
